==> rubicore-core.2.11.1.zip: rubicore-core/repositories/user/user-repository.php <==
<?php

namespace Rubicore\Core;

final class User_Repository {
	private string $user_node_table;
	private string $user_table;

	function __construct () {
		$this->user_node_table = Db_Helper::table('user_node');
		$this->user_table = Db_Helper::table('users');
	}

	public function get(array $params) : array
	{
		$q = new Query_Builder_Helper($params, User_Query::$fields);
		$where = "";

		$where = Query_Helper::add_where(boolval($q->search_query), $where, "AND", $q->search_query);
		$where = Query_Helper::add_where(boolval($q->filter_query), $where, "AND", $q->filter_query);

		$count_query = Query_Helper::get_count("FROM $this->user_table $where");
		$total_count = Db_Helper::get_row($count_query)->num_rows;

		Response_Helper::set_pagination_total_header($total_count);


		$main_query = "SELECT * FROM $this->user_table $where $q->order_by_query $q->limit_query";

		$rows = Db_Helper::get_rows($main_query);

		$role_repo = new Role_Repository();

		foreach ($rows as $row) {
			$row->meta = $this->get_meta($row->ID);
			$row->roles = $role_repo->get($row->ID);
		}

		return $rows;
	}

	public function get_by_id($input) : ?object
	{
		$role_repo = new Role_Repository();

		$user = is_numeric($input) ?
			Db_Helper::get_row("SELECT * FROM $this->user_table WHERE id = %d", [$input]) :
			Db_Helper::get_row("SELECT * FROM $this->user_table WHERE user_login = %s", [$input]);


		if ($user) {
			$user->meta = $this->get_meta($user->ID);
			$user->roles = $role_repo->get($user->ID);
		}

		return $user;
	}

	public function get_meta(int $id) : array
	{
		return get_user_meta($id);
	}

	public function update_meta(int $user_id, User_Meta_Entity $meta) : void
	{
		foreach ($meta->to_array() as $key => $value) {
			if (!is_null($value)) {
				update_user_meta($user_id, $key, $value);
			}
		}
	}

	public function get_users_by_node(int $node_id) : array
	{
		$rows = Db_Helper::get_rows(
			"SELECT uci.user_id FROM $this->user_node_table AS uci
			WHERE uci.node_id = %d
			AND uci.main = true", [$node_id]
		);

		$ret = [];

		foreach($rows as $row) {
			$ret[] = intval($row->user_id);
		}

		return $ret;
	}
}

==> rubicore-core.2.12.0-rc.0.zip: rubicore-core/repositories/user/user-repository.php <==
<?php

namespace Rubicore\Core;

final class User_Repository {
	private string $user_node_table;
	private string $user_table;

	function __construct () {
		$this->user_node_table = Db_Helper::table('user_node');
		$this->user_table = Db_Helper::table('users');
		$this->usermeta_table = Db_Helper::table('usermeta');
	}

	public function get(array $params) : array
	{
		$q = new Query_Builder_Helper($params, User_Query::$fields);
		$where = "";

		$where = Query_Helper::add_where(boolval($q->search_query), $where, "AND", $q->search_query);
		$where = Query_Helper::add_where(boolval($q->filter_query), $where, "AND", $q->filter_query);

		$where = Query_Helper::add_where(true, $where, "AND", "
			NOT EXISTS (
				SELECT * FROM {$this->usermeta_table} AS um
				WHERE um.user_id = u.ID
				AND um.meta_key = 'external'
				AND um.meta_value = true
			)
		");

		$count_query = Query_Helper::get_count("FROM $this->user_table AS u $where");
		$total_count = Db_Helper::get_row($count_query)->num_rows;

		Response_Helper::set_pagination_total_header($total_count);


		$main_query = "SELECT * FROM $this->user_table AS u $where $q->order_by_query $q->limit_query";

		$rows = Db_Helper::get_rows($main_query);

		$role_repo = new Role_Repository();

		foreach ($rows as $row) {
			$row->meta = $this->get_meta($row->ID);
			$row->roles = $role_repo->get($row->ID);
		}

		return $rows;
	}

	public function get_by_id($input) : ?object
	{
		$role_repo = new Role_Repository();

		$user = is_numeric($input) ?
			Db_Helper::get_row("SELECT * FROM $this->user_table WHERE id = %d", [$input]) :
			Db_Helper::get_row("SELECT * FROM $this->user_table WHERE user_login = %s", [$input]);


		if ($user) {
			$user->meta = $this->get_meta($user->ID);
			$user->roles = $role_repo->get($user->ID);
		}

		return $user;
	}

	public function get_meta(int $id) : array
	{
		return get_user_meta($id);
	}

	public function update_meta(int $user_id, User_Meta_Entity $meta) : void
	{
		foreach ($meta->to_array() as $key => $value) {
			if (!is_null($value)) {
				update_user_meta($user_id, $key, $value);
			}
		}
	}

	public function get_users_by_node(int $node_id) : array
	{
		$rows = Db_Helper::get_rows(
			"SELECT uci.user_id FROM $this->user_node_table AS uci
			WHERE uci.node_id = %d
			AND uci.main = true", [$node_id]
		);

		$ret = [];

		foreach($rows as $row) {
			$ret[] = intval($row->user_id);
		}

		return $ret;
	}
}
